##############################################################################
# 
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
# 
# Copyright (c) Digital Creations.  All rights reserved.
# 
# This license has been certified as Open Source(tm).
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
# 
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
# 
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
# 
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
# 
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
# 
# 
# Disclaimer
# 
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
# 
# 
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
# 
##############################################################################
"""
"""

ADD_CONTENT_PERMISSION = 'Add portal content'

import Globals
import zLOG
from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.CMFCorePermissions import View
from Products.CMFCore.CMFCorePermissions import ManageProperties
from AccessControl import ClassSecurityInfo
from Products.CMFCore.PortalContent import PortalContent
from Products.CMFDefault.DublinCore import DefaultDublinCoreImpl
#from Globals import PersistentList

from Products.CMFCore import CMFCorePermissions
from Products.CMFCore.WorkflowCore import WorkflowAction, afterCreate

factory_type_information = {
      'id': 'MediaShow',
      'meta_type': 'Media Manager Show',
      'description': 'Use show to make new Media Show',
      'product': 'MMMCore',
      'icon': 'file_icon.gif',
      'factory': 'addMediaShow',
      'filter_content_types': 0,
      'immediate_view': 'mediashow_edit_form',
      'actions': 
	      ({'name': 'View',
	        'action': 'mediashow_view',
		'permissions': ('View',),
		'category': 'object'},
	       {'name': 'Edit',
	        'action': 'mediashow_edit_form',
		'permissions': ('Modify portal content',),
		'category': 'object'},
	       {'name': 'Play',
	        'action': 'show_play_form',
		'permissions': ('View',),
		'category': 'object'})
       }


class MediaShow( PortalContent
          , DefaultDublinCoreImpl
          ):
    """
        A Link
    """

    meta_type='Media Manager Show'
    portal_type='Object'
    effective_date = expiration_date = None
    _isDiscussable = 1

    security = ClassSecurityInfo()

    def __init__( self
                , id
                , title=''
                , description=''
                ):
        DefaultDublinCoreImpl.__init__(self)
        self.id=id
        self.title=title
        self.clips = [] 
        self.description=description
	zLOG.LOG("MediaShow", -100, "Made MasterFile %s" % (id))

    def listClips( self ):
	"""
	  List All offsets available
	"""
	zLOG.LOG("MediaShow", zLOG.INFO, "Listing logics\nCurrent:\n%s" % (self.clips))
	return tuple(self.clips)

    security.declareProtected(View, 'lookup')
    def lookup(self, userset=None):
        """
	  returns the URL nedded
	"""
	zLOG.LOG("MediaShow", -100, "Lookup called")
	#ob = self.unrestrictedTraverse('../..', default=None)
	#if ob is not None:
	relative = "%s" % (self.id)
	ob = self.unrestrictedTraverse('..', default=None)
	if ob is None:
	    raise "DEBUG", "MasterFile not contained in Medianet"
	while not (ob.meta_type == "Media Manager Medianet"):
	    obn = ob.unrestrictedTraverse('..', default=None)
	    if obn is None:
                raise "DEBUG", "MasterFile not contained in Medianet"
	    if not (obn.meta_type == "Media Manager Medianet"):
		relative = "%s/%s" % (ob.id,relative)
            ob = obn 
	    #zLOG.LOG ("MasterFile", -100, "Found %s %s" % (ob.absolute_url(), ob.meta_type))

	return  ob.lookupMasterFile(object=self, name=relative, userset=userset)

    security.declareProtected(View, 'getClip')
    def getClip( self, pIndex ):
	index = int(pIndex)
	zLOG.LOG("MediaShow", zLOG.TRACE, "Fetching logic %s return: %s" % (index, self.clips[index]))
	return self.clips[index]
	
    security.declareProtected(ManageProperties, 'moveUp')
    def moveUp( self, pIndex ):
	"""
	"""
	index = int(pIndex)
	#raise "DEBUG", "Assign %s to %s" % (id, offset)
	zLOG.LOG("MediaShow", -100, "moveUp %s" % (index))
	if index>0 and index<len(self.clips):
	  old = self.clips[index-1]
	  self.clips[index-1] = self.clips[index]
	  self.clips[index] = old
	  self._p_changed = 1

    security.declareProtected(ManageProperties, 'moveDown')
    def moveDown( self, pIndex ):
        """
	"""
	index=int(pIndex)
	zLOG.LOG("MediaShow", zLOG.TRACE, "moveDown %s" % (index))
	if index<len(self.clips)-1 and index>=0:
	  old = self.clips[index+1]
	  self.clips[index+1] = self.clips[index]
	  self.clips[index] = old
	  self._p_changed = 1

    security.declareProtected(ManageProperties, 'delete')
    def delete( self, pIndex ):
        """
	"""
	index=int(pIndex)
	zLOG.LOG("MediaShow", zLOG.INFO, "delete %s %s" % (index, len(self.clips)))
	if index>=0 and index<len(self.clips):
	  del self.clips[index]
	  self._p_changed = 1
	  zLOG.LOG("MediaShow", zLOG.INFO, "Deleted %s" %(index))

    security.declareProtected(ManageProperties, 'append')
    def append( self, clip ):
	"""
	"""
	zLOG.LOG("MediaShow", zLOG.INFO, "append %s" % (clip))
	self.clips.append(clip)
	self._p_changed = 1

    def SearchableText(self):
        """
            text for indexing
        """
        return "%s %s" % (self.title, self.description)

def addMediaShow(self, id, title='', REQUEST=None):
	ob=MediaShow(id,title)
	self._setObject(id, ob)

Globals.InitializeClass(MediaShow)

from Products.CMFCore.register import registerPortalContent
registerPortalContent(MediaShow,
                      constructors=(addMediaShow,),
		      action='mediashow_edit_form',
		      icon='file_icon.gif')
