##############################################################################
# 
# Zope Public License (ZPL) Version 1.0
# -------------------------------------
# 
# Copyright (c) Digital Creations.  All rights reserved.
# 
# This license has been certified as Open Source(tm).
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions in source code must retain the above copyright
#    notice, this list of conditions, and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions, and the following disclaimer in
#    the documentation and/or other materials provided with the
#    distribution.
# 
# 3. Digital Creations requests that attribution be given to Zope
#    in any manner possible. Zope includes a "Powered by Zope"
#    button that is installed by default. While it is not a license
#    violation to remove this button, it is requested that the
#    attribution remain. A significant investment has been put
#    into Zope, and this effort will continue if the Zope community
#    continues to grow. This is one way to assure that growth.
# 
# 4. All advertising materials and documentation mentioning
#    features derived from or use of this software must display
#    the following acknowledgement:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    In the event that the product being advertised includes an
#    intact Zope distribution (with copyright and license included)
#    then this clause is waived.
# 
# 5. Names associated with Zope or Digital Creations must not be used to
#    endorse or promote products derived from this software without
#    prior written permission from Digital Creations.
# 
# 6. Modified redistributions of any form whatsoever must retain
#    the following acknowledgment:
# 
#      "This product includes software developed by Digital Creations
#      for use in the Z Object Publishing Environment
#      (http://www.zope.org/)."
# 
#    Intact (re-)distributions of any official Zope release do not
#    require an external acknowledgement.
# 
# 7. Modifications are encouraged but must be packaged separately as
#    patches to official Zope releases.  Distributions that do not
#    clearly separate the patches from the original work must be clearly
#    labeled as unofficial distributions.  Modifications which do not
#    carry the name Zope may be packaged in any form, as long as they
#    conform to all of the clauses above.
# 
# 
# Disclaimer
# 
#   THIS SOFTWARE IS PROVIDED BY DIGITAL CREATIONS ``AS IS'' AND ANY
#   EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#   IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
#   PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL DIGITAL CREATIONS OR ITS
#   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
#   LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
#   USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
#   ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
#   OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
#   OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#   SUCH DAMAGE.
# 
# 
# This software consists of contributions made by Digital Creations and
# many individuals on behalf of Digital Creations.  Specific
# attributions are listed in the accompanying credits file.
# 
##############################################################################
"""
    Portal folders organize content.
"""
ADD_FOLDERS_PERMISSION = 'Add portal folders'

import Globals, re, base64, marshal, string
from Products.CMFCore import CMFCorePermissions

from Products.CMFCore.CMFCorePermissions import AddPortalFolders
from Products.CMFCore.CMFCorePermissions import AddPortalContent
from Products.CMFCore.CMFCorePermissions import ViewManagementScreens
from Products.CMFCore.CMFCorePermissions import View
from Globals import DTMLFile
from OFS.DTMLMethod import DTMLMethod
from AccessControl import getSecurityManager, ClassSecurityInfo
from Acquisition import aq_base
from Products.CMFCore.PortalFolder import PortalFolder
from Products.CMFCore.PortalFolder import manage_addPortalFolder
from OFS.Folder import Folder
from BTree import BTree
from DocumentTemplate.DT_Util import html_quote
from urllib import quote
import zLOG

try:
    from cStringIO import StringIO
except ImportError:
    from StringIO import StringIO

# Factory type information -- makes PortalBTreeFolder objects play nicely
# with the Types Tool (portal_types)
factory_type_information =  {
     'id': 'Medianet',
     'meta_type': 'Media Manager Medianet',
     'description': 'Use folders to put content in categories.',
     'product': 'MMMCore',
     'icon': 'folder_icon.gif',
     'factory': 'manage_addMedianetFolder',
     'filter_content_types': 0,
     'immediate_view': 'folder_contents',
     'actions': 
            ({'name': 'View',
              'action': '',
              'permissions': ('View',),
              'category': 'folder'},
             {'name': 'Change Folder',
              'action': 'folder_edit_form',
              'permissions': ('Manage properties',),
              'category': 'folder'},
             )
     }

listtext0 = '''<select name="ids:list" multiple size="%s">
'''
listtext1 = '''<option>%s</option>
'''
listtext2 = '''</select>
'''

_marker = []  # Create a new marker object.

try:
    higher_getattr = PortalFolder.inheritedAttribute('__getattr__')
except:
    def higher_getattr(self, name):
        raise AttributeError, name

class MedianetFolder( PortalFolder ):
    """
        Like a PortalFolder but uses a BTree for storage with
        appropriate management UI.
    """
    meta_type = 'Media Manager Medianet'
    portal_type = 'Folder'

    manage_options=(
        ({'label':'Contents', 'action':'manage_main',},
         ) + Folder.manage_options[1:]
        )

    security = ClassSecurityInfo()

    description = ''

    def __init__( self, id, title='' ):
        # I can't figure out how to call two overridden __init__ methods
        # using inheritedAttribute, so I'll just duplicate their contents
        # here.
        #BTreeFolder.__init__(self)
        #self._tree = BTree()
        #PortalFolder.__init__(self, id, title)
        self.id = id
        self.title = title

    security.declareProtected(View, 'embedPlayer')
    #embedPlayer = DTMLMethod('dtml/embedPlayer.dtml', __name__='embedPlayer')
    embedPlayer = DTMLFile('dtml/embedPlayer', globals())

    security.declareProtected(View, 'lookupPlayerSource')
    def lookupPlayerSource(self, file, userset=None):
        """
	  Finds the url for a player to access
	"""
	#url = self.absolute_url(relative=file)
	ob = self.unrestrictedTraverse(file, default=None)
	if ob is not None:
            return ob.lookup(userset)

        raise "DEBUG", "Unkown object %s" % (file)

    def lookupMasterFile(self, object, name, userset=None):
	ob = self['Logic'][object.listLogics()[0]]
	zLOG.LOG ("Medianet", 0, "Test %s" % (ob.Protocol))

	if ob.Port < 1:
	  return "%s://%s%s%s%s" % (ob.Protocol, ob.Host, ob.PrePath, name, ob.PostPath)

	return "%s://%s:%s%s%s%s" % (ob.Protocol, ob.Host, ob.Port, ob.PrePath, name, ob.PostPath)
    
    security.declareProtected(AddPortalFolders, 'manage_addMedianetFolder')
    def manage_addMedianetFolder(self, id, title='', REQUEST=None):
        """Add a new MedianetFolder object with id *id*.
        """
        ob = MedianetFolder(id, title)
        self._setObject(id, ob)
        if REQUEST is not None:
            return self.folder_contents(
                self, REQUEST, portal_status_message="Folder added")
	manage_addPortalFolder(ob, id='Archive', title='Masterfile Archive', REQUEST=None)
	manage_addPortalFolder(ob, id='Logic', title='Server Logic', REQUEST=None)
    
    security.setPermissionDefault(AddPortalContent, ('Owner','Manager'))
    security.setPermissionDefault(AddPortalFolders, ('Owner','Manager'))

manage_addMedianetFolder = MedianetFolder.manage_addMedianetFolder
manage_addMedianetFolderForm = DTMLFile( 'folderAdd', globals() )

Globals.InitializeClass(MedianetFolder)

# PortalContent classes need to be registered.  This installs the
# class's factory method and icon.
from Products.CMFCore.register import registerPortalContent
registerPortalContent(MedianetFolder,
                      constructors=(MedianetFolder.manage_addMedianetFolder,),
                      action='manage_addMedianetFolderForm',
                      icon="folder_icon.gif",
                      productGlobals=globals())
